@@ -11,7 +11,7 @@ import datetime
 ############################################################
 
 """
-See RtmClient class for API documentation.
+See RtmClient class below for API documentation.
 
 The following structures (namedtuples) are used to represent
 data downloaded from RememberTheMilk
@@ -256,7 +256,7 @@ class RtmClient(object):
         r = None
 
         if set_tags is not None:
-            tag_text = ", ".join(set_tags)
+            tag_text = ",".join(set_tags)
             r = self.connector.call(
                 "rtm.tasks.setTags",
                 timeline = timeline,
@@ -327,6 +327,24 @@ class RtmClient(object):
 
         return task
 
+    def move_task(self, task_key, new_list_id):
+        """
+        Moves given task to new list. Returns current task state.
+        Note that task key changes after this operation!
+        """
+        timeline = self._get_timeline()
+        r = self.connector.call(
+            "rtm.tasks.moveTo",
+            timeline = timeline,
+            from_list_id = task_key.list_id,
+            to_list_id = new_list_id,
+            taskseries_id = task_key.taskseries_id,
+            task_id = task_key.task_id)
+        task = RtmClient._parse_task(
+            new_list_id,
+            RtmClient._ensure_element_is_singular(r['list']['taskseries']))
+        return task
+
     def add_task_note(self, task_key, 
                       note_title, note_text):
         """
@@ -555,6 +573,10 @@ class RtmClient(object):
         or so:
 
            "tags":{"tag":["@dom","testy"]}
+
+        or even so:
+
+           "tags":{"tag":"@dom"}
         
         @param item analyzed element in the tree (for the above example, either [] or {"tag":["@dom","testy"]})
         @param tag_name name of the sub-item
@@ -565,7 +587,10 @@ class RtmClient(object):
                 raise RtmDataException("Block expected to be empty list or dictionary is nonempty list: %s\nNotify developer" % str(item))
             return default_value
         else:
-            return item[tag_name]
+            v = item[tag_name]
+            if type(v) is not list:
+                return [v]
+            return v
 
     @staticmethod
     def _wrap_element_as_list_if_singular(item):
